/* ***** BEGIN LICENSE BLOCK *****
 *   Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is multisearch.
 *
 * The Initial Developer of the Original Code is
 *
 * Einar Egilsson. (email: multisearch@einaregilsson.com)
 *
 * Portions created by the Initial Developer are Copyright (C) 2007
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var MultiSearch = {

    delimiter : null,

    onLoad : function(loadEvent) {
        var searchbar = document.getElementById('searchbar');
        //Save the old search for cases without delim..
        searchbar.normalDoSearch = searchbar.doSearch;
        MultiSearch.loadDelimiter();


        //observe delimiter changes
        Components.classes["@mozilla.org/preferences-service;1"]
            .getService(Components.interfaces.nsIPrefBranchInternal)
                .addObserver('extensions.multisearch', MultiSearch, false);


        //...and then use our modified version
        searchbar.doSearch = function(aData, aInNewTab) { 
          var delim = MultiSearch.delimiter;

          if (aData.indexOf(delim) == -1) {
            this.normalDoSearch(aData, aInNewTab);
            return;
          }

          var parts = aData.split(delim);
          var postData = null;
            
          for each(part in parts) {

            part = part.replace(/^\s*|\s*$/g, '');
              // null parameter below specifies HTML response for search
              var submission = this.currentEngine.getSubmission(part, null);
              if (submission) {
                var url = submission.uri.spec;
                postData = submission.postData;
              }

            getBrowser().loadOneTab(url, null, null, postData, false, false);
            if (gURLBar)
              gURLBar.value = url;
          }
        
          content.focus();
        };

        setTimeout(MultiSearch.overrideTabMixPlus, 5000);
    },


    //Tab Mix Plus replaces some things in the handleSearchCommand function which
    //will disable MultiSearch. So we'll do this huge hack to override that :)
    overrideTabMixPlus : function() {
        var searchbar = document.getElementById('searchbar');
        if(searchbar && "handleSearchCommand" in searchbar) {
            
            var oldfunc = searchbar.handleSearchCommand.toString();
            oldfunc = oldfunc.replace(/TMP_SearchLoadURL[^]*/, 'this.doSearch(textValue, where) \n };');
            eval("searchbar.handleSearchCommand ="+oldfunc.toString());
            oldfunc = searchbar.handleSearchCommand.toString();
        }

    },

    observe : function(aSubject, aTopic, aData) {
        //We're only observing for this so just always load delimiter
        MultiSearch.loadDelimiter();
    },

    loadDelimiter : function() {
        MultiSearch.delimiter = Components.classes["@mozilla.org/preferences-service;1"]
                                    .getService(Components.interfaces.nsIPrefBranch)        
                                        .getCharPref('extensions.multisearch.delimiter');
    }

};

window.addEventListener("load", MultiSearch.onLoad, false);


